Learn R Programming

CohortCharacteristics (version 1.1.1)

summariseCohortAttrition: Summarise attrition associated with cohorts in a cohort table

Description

Summarise attrition associated with cohorts in a cohort table

Usage

summariseCohortAttrition(cohort, cohortId = NULL)

Value

A summary of the attrition for the cohorts in the cohort table.

Arguments

cohort

A cohort_table object.

cohortId

A cohort definition id to restrict by. If NULL, all cohorts will be included.

Examples

Run this code
# \donttest{
library(CohortCharacteristics)
library(dplyr, warn.conflicts = FALSE)

cdm <- mockCohortCharacteristics()

summariseCohortAttrition(cohort = cdm$cohort1) |>
  glimpse()

# }

Run the code above in your browser using DataLab