- cohort
A cohort_table object.
- cohortId
A cohort definition id to restrict by. If NULL, all cohorts
will be included.
- strata
A list of variables to stratify results. These variables
must have been added as additional columns in the cohort table.
- counts
TRUE or FALSE. If TRUE, record and person counts will
be produced.
- demographics
TRUE or FALSE. If TRUE, patient demographics (cohort
start date, cohort end date, age, sex, prior observation, and future
observation will be summarised).
- ageGroup
A list of age groups to stratify results by.
- tableIntersectFlag
A list of arguments that uses
PatientProfiles::addTableIntersectFlag() to add variables to summarise.
- tableIntersectCount
A list of arguments that uses
PatientProfiles::addTableIntersectCount() to add variables to summarise.
- tableIntersectDate
A list of arguments that uses
PatientProfiles::addTableIntersectDate() to add variables to summarise.
- tableIntersectDays
A list of arguments that uses
PatientProfiles::addTableIntersectDays() to add variables to summarise.
- cohortIntersectFlag
A list of arguments that uses
PatientProfiles::addCohortIntersectFlag() to add variables to summarise.
- cohortIntersectCount
A list of arguments that uses
PatientProfiles::addCohortIntersectCount() to add variables to summarise.
- cohortIntersectDate
A list of arguments that uses
PatientProfiles::addCohortIntersectDate() to add variables to summarise.
- cohortIntersectDays
A list of arguments that uses
PatientProfiles::addCohortIntersectDays() to add variables to summarise.
- conceptIntersectFlag
A list of arguments that uses
PatientProfiles::addConceptIntersectFlag() to add variables to summarise.
- conceptIntersectCount
A list of arguments that uses
PatientProfiles::addConceptIntersectCount() to add variables to summarise.
- conceptIntersectDate
A list of arguments that uses
PatientProfiles::addConceptIntersectDate() to add variables to summarise.
- conceptIntersectDays
A list of arguments that uses
PatientProfiles::addConceptIntersectDays() to add variables to summarise.
- otherVariables
Other variables contained in cohort that you want to be
summarised.
- estimates
To modify the default estimates for a variable.
By default: 'min', 'q25', 'median', 'q75', 'max' for "date", for "numeric" and
"integer" variables ("numeric" and "integer" also use 'mean' and 'sd'
estimates). 'count' and 'percentage' for "categorical" and "binary".
You have to provide them as a list: list(age = c("median", "density")). You
can also use 'date', 'numeric', 'integer', 'binary', 'categorical',
'demographics', 'intersect', 'other', 'table_intersect_count', ... as valid labels,
see available estimates using PatientProfiles::availableEstimates()
- weights
Column in cohort that points to weights of each individual.