powered by
Summarise attrition associated with cohorts in a cohort table
summariseCohortAttrition(cohort, cohortId = NULL)
A summary of the attrition for the cohorts in the cohort table.
A cohort_table object.
A cohort definition id to restrict by. If NULL, all cohorts will be included.
# \donttest{ library(CohortCharacteristics) library(dplyr, warn.conflicts = FALSE) cdm <- mockCohortCharacteristics() summariseCohortAttrition(cohort = cdm$cohort1) |> glimpse() # }
Run the code above in your browser using DataLab