Learn R Programming

CohortCharacteristics (version 1.1.1)

summariseCohortCount: Summarise counts for cohorts in a cohort table

Description

Summarise counts for cohorts in a cohort table

Usage

summariseCohortCount(cohort, cohortId = NULL, strata = list())

Value

A summary of counts of the cohorts in the cohort table.

Arguments

cohort

A cohort_table object.

cohortId

A cohort definition id to restrict by. If NULL, all cohorts will be included.

strata

A list of variables to stratify results. These variables must have been added as additional columns in the cohort table.

Examples

Run this code
# \donttest{
library(CohortCharacteristics)
library(dplyr, warn.conflicts = FALSE)

cdm <- mockCohortCharacteristics()

summariseCohortCount(cohort = cdm$cohort1) |>
  glimpse()

# }

Run the code above in your browser using DataLab