powered by
Summarise counts for cohorts in a cohort table
summariseCohortCount(cohort, cohortId = NULL, strata = list())
A summary of counts of the cohorts in the cohort table.
A cohort_table object.
A cohort definition id to restrict by. If NULL, all cohorts will be included.
A list of variables to stratify results. These variables must have been added as additional columns in the cohort table.
# \donttest{ library(CohortCharacteristics) library(dplyr, warn.conflicts = FALSE) cdm <- mockCohortCharacteristics() summariseCohortCount(cohort = cdm$cohort1) |> glimpse() # }
Run the code above in your browser using DataLab