powered by
Summarise overlap between cohorts in a cohort table
summariseCohortOverlap( cohort, cohortId = NULL, strata = list(), overlapBy = "subject_id" )
A summary of overlap between cohorts in the cohort table.
A cohort_table object.
A cohort definition id to restrict by. If NULL, all cohorts will be included.
A list of variables to stratify results. These variables must have been added as additional columns in the cohort table.
Columns in cohort to use as record identifiers.
# \donttest{ library(CohortCharacteristics) library(dplyr, warn.conflicts = FALSE) cdm <- mockCohortCharacteristics() summariseCohortOverlap(cdm$cohort2) |> glimpse() # }
Run the code above in your browser using DataLab