powered by
Summarise timing between entries into cohorts in a cohort table
summariseCohortTiming( cohort, cohortId = NULL, strata = list(), restrictToFirstEntry = TRUE, estimates = c("min", "q25", "median", "q75", "max", "density"), density = lifecycle::deprecated() )
A summary of timing between entries into cohorts in the cohort table.
A cohort_table object.
A cohort definition id to restrict by. If NULL, all cohorts will be included.
A list of variables to stratify results. These variables must have been added as additional columns in the cohort table.
If TRUE only an individual's first entry per cohort will be considered. If FALSE all entries per individual will be considered.
Summary statistics to use when summarising timing.
deprecated.
# \donttest{ library(CohortCharacteristics) library(dplyr, warn.conflicts = FALSE) cdm <- mockCohortCharacteristics(numberIndividuals = 100) summariseCohortTiming(cdm$cohort2) |> glimpse() # }
Run the code above in your browser using DataLab